Package: multibias
Type: Package
Title: Multiple Bias Analysis in Causal Inference
Version: 1.7.3
Date: 2026-04-20
Authors@R: person("Paul", "Brendel", email = "pcbrendel@gmail.com",
    role = c("aut", "cre", "cph"))
Maintainer: Paul Brendel <pcbrendel@gmail.com>
Description: Quantify exposure-outcome causal effects
    with adjustment for multiple biases. The functions can
    simultaneously adjust for any combination of uncontrolled confounding,
    exposure/outcome misclassification, and selection bias.
    The underlying method generalizes the combination of inverse
    probability of selection weighting with predictive value weighting.
    Simultaneous multi-bias analysis can be used to enhance the validity
    and transparency of real-world evidence obtained from observational,
    longitudinal studies. Based on the work from Paul Brendel, Aracelis Torres, and Onyebuchi Arah (2023) <doi:10.1093/ije/dyad001>.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
Depends: R (>= 4.2.0)
RoxygenNote: 7.3.2
Imports: dplyr (>= 1.1.3), lifecycle (>= 1.0.3), magrittr (>= 2.0.3),
        rlang (>= 1.1.1), broom (>= 1.0.5), purrr (>= 1.0.0), ggplot2
        (>= 3.5.0)
Suggests: knitr, rmarkdown, MASS, testthat (>= 3.0.0), vdiffr (>=
        1.0.5)
URL: https://github.com/pcbrendel/multibias,
        http://www.paulbrendel.com/multibias/
BugReports: https://github.com/pcbrendel/multibias/issues
Config/testthat/edition: 3
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-04-20 22:45:03 UTC; pbrendel
Author: Paul Brendel [aut, cre, cph]
Repository: CRAN
Date/Publication: 2026-04-20 23:30:02 UTC
Built: R 4.5.2; ; 2026-04-21 01:25:54 UTC; unix
