# Generated by roxygen2: do not edit by hand

S3method(print,bias_params)
S3method(print,data_observed)
S3method(print,data_validation)
S3method(summary,data_observed)
export(bias_params)
export(data_observed)
export(data_validation)
export(multibias_adjust)
export(multibias_plot)
import(dplyr)
importFrom(broom,tidy)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(rlang,.data)
importFrom(stats,as.formula)
importFrom(stats,binomial)
importFrom(stats,coef)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,plogis)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,rbinom)
importFrom(stats,rnorm)
importFrom(stats,sd)
importFrom(stats,vcov)
